@@ -9,7 +9,7 @@ use vars qw/@ISA/;
 
 use DBI;
 
-our $VERSION = '0.05';
+our $VERSION = '0.08';
 
 
 =head1 NAME
@@ -56,6 +56,7 @@ sub new {
 	uri => undef,
 	passwd => undef,
 	XMLELEMENT => 'user',
+	XMLPREFIX => 'user',
 	XMLNS => 'http://www.kjetil.kjernsmo.net/software/TABOO/NS/User/Output',
 	ONFILE => undef,
     };
@@ -156,7 +157,13 @@ The user's encrypted password. Allthough it I<is> encrypted, you may not want to
 
 =head1 XML representation
 
-The C<write_xml()> method, implemented in the parent class, can be used to create an XML representation of the data in the object. The above names will be used as element names. The C<xmlelement()> and C<xmlns()> methods can be used to set the name of the root element and the namespace respectively. Usually, it doesn't make sense to change the defaults, which are 
+The C<write_xml()> method, implemented in the parent class, can be
+used to create an XML representation of the data in the object. The
+above names will be used as element names. The C<xmlelement()>,
+C<xmlns()> and C<xmlprefix()> methods can be used to set the name of
+the root element, the namespace URI and namespace prefix
+respectively. Usually, it doesn't make sense to change the default
+namespace or prefix, that are
 
 
 =over
@@ -165,6 +172,8 @@ The C<write_xml()> method, implemented in the parent class, can be used to creat
 
 =item * C<http://www.kjetil.kjernsmo.net/software/TABOO/NS/User/Output>
 
+=item * C<user>
+
 =back
 
 
